from typing import Literal

TransformOrigin = Literal[
    'center',
    'top',
    'top-right',
    'right',
    'bottom-right',
    'bottom',
    'bottom-left',
    'left',
    'top-left',
]
